@@ -1,5 +1,4 @@
-// +build go1.7
-// +build !go1.8
+// +build go1.8
 
 package gorequest
 
@@ -15,6 +14,7 @@ func (s *SuperAgent) safeModifyTransport() {
     oldTransport := s.Transport
     s.Transport = &http.Transport{
         Proxy:                  oldTransport.Proxy,
+        DialContext:            oldTransport.DialContext,
         Dial:                   oldTransport.Dial,
         DialTLS:                oldTransport.DialTLS,
         TLSClientConfig:        oldTransport.TLSClientConfig,
@@ -23,12 +23,12 @@ func (s *SuperAgent) safeModifyTransport() {
         DisableCompression:     oldTransport.DisableCompression,
         MaxIdleConns:           oldTransport.MaxIdleConns,
         MaxIdleConnsPerHost:    oldTransport.MaxIdleConnsPerHost,
+        IdleConnTimeout:        oldTransport.IdleConnTimeout,
         ResponseHeaderTimeout:  oldTransport.ResponseHeaderTimeout,
         ExpectContinueTimeout:  oldTransport.ExpectContinueTimeout,
         TLSNextProto:           oldTransport.TLSNextProto,
-        // new in go1.7
-        DialContext:            oldTransport.DialContext,
-        IdleConnTimeout:        oldTransport.IdleConnTimeout,
         MaxResponseHeaderBytes: oldTransport.MaxResponseHeaderBytes,
+        // new in go1.8
+        ProxyConnectHeader:     oldTransport.ProxyConnectHeader,
     }
 }
